HttpRpcClient

Struct HttpRpcClient 

pub struct HttpRpcClient { /* private fields */ }
An HTTP RPC client for Monero.

Implementations

Source

impl HttpRpcClient

pub async fn new(address: Option<String>) -> Self

Create an HttpRpcClient.

address should be an HTTP URL pointing to a monerod.

If None is provided the default is used: LOCALHOST_RPC_URL.

Note that for Self::get_verified_block_information to work, the monerod must be in unrestricted mode such that some fields (e.g. pow_hash) appear in the JSON response.

Panics

This panics if the address is invalid or a connection could not be made.

pub async fn get_verified_block_information( &self, height: usize, ) -> VerifiedBlockInformation

Request data and map the response to a VerifiedBlockInformation.

Panics

This function will panic at any error point, e.g., if the node cannot be connected to, if deserialization fails, etc.

pub async fn get_transaction_verification_data<'a>( &self, tx_hashes: &'a [[u8; 32]], ) -> impl Iterator<Item = VerifiedTransactionInformation> + 'a

Request data and map the response to a VerifiedTransactionInformation.

Panics

This function will panic at any error point, e.g., if the node cannot be connected to, if deserialization fails, etc.